//=============================================================================
// Unreal Texture Upgrade Mutator
// Gerald Lance Tindall aka. {KDS}BOZO aka. <NDP>BOZO aka. LordBozo
// bozo@kds-clan.com
// CODE NOT FOR REUSE WITHOUT PRIOR PERMISSION OF THE AUTHOR
//=============================================================================
// UnrealTextureUpgrade.UTUClient_Decoration:
// Allows the dynamic changeout of the textures that will be utilized
// for any mesh referenced by the supported classnames at runtime.
// The replacement funcionality is client specific to allow for optional S3TC use.
// Designed to support regular and/or S3TC textures.
//
// VERSION 0.1 BETA
//
//=============================================================================
class UTUClient_Decoration expands Actor config (UnrealTextureUpgrade);

// NOTE: Add a check vs correct Mesh within class also.
// NOTE: Add a check vs correct Default Texture assigned also.
// NOTE: Add a check vs bMeshEnviromap = True
// NOTE: Add a check vs bParticles = True
// NOTE: Add a check vs DrawType = DT_Mesh

struct TexReplacer_type
{
   var() config string TClass;   // Target Class

   var() config string R0_Name;  // Replacement Texture Name (Slot 0)
   var() config string R1_Name;  // Replacement Texture Name (Slot 1)
   var() config string R2_Name;  // Replacement Texture Name (Slot 2)
   var() config string R3_Name;  // Replacement Texture Name (Slot 3)
   var() config string R4_Name;  // Replacement Texture Name (Slot 4)
   var() config string R5_Name;  // Replacement Texture Name (Slot 5)
   var() config string R6_Name;  // Replacement Texture Name (Slot 6)
   var() config string R7_Name;  // Replacement Texture Name (Slot 7)

   var() config string D0_Name;  // Default Texture Name (Slot 0)
   var() config string D1_Name;  // Default Texture Name (Slot 1)
   var() config string D2_Name;  // Default Texture Name (Slot 2)
   var() config string D3_Name;  // Default Texture Name (Slot 3)
   var() config string D4_Name;  // Default Texture Name (Slot 4)
   var() config string D5_Name;  // Default Texture Name (Slot 5)
   var() config string D6_Name;  // Default Texture Name (Slot 6)
   var() config string D7_Name;  // Default Texture Name (Slot 7)

};

var() config TexReplacer_type TexReplacer_Decoration[100];

var int NumReplacementClasses;

var UTUTexRef UTUTexRefList;
var UTUTexRef UTUR;

var() config bool Debug;

var string EngineVersion;
var class<RenderDevice>   GameRenderDevice;


//=============================================================================
// UTUClient_Decoration.PreBeginPlay
//=============================================================================
event PreBeginPlay()
{
   local int i, j;
   local string TempRefName;

   if( Level.Netmode != NM_DedicatedServer && Level.Netmode != NM_ListenServer )
   {
      if(PlayerPawn(Owner)==None)
      {
         self.Destroy();
      }else
      {
         GameRenderDevice=class'Engine'.default.GameRenderDevice;
         log("Game Render Device :"@GameRenderDevice);

         EngineVersion=PlayerPawn(Owner).Level.EngineVersion;
         log("Engine Version :"@EngineVersion);
      }// endif

      NumReplacementClasses=0;

      for (i=0;i<100;i++)
      {
         if(TexReplacer_Decoration[i].TClass!="")
         {
            if(UTUTexRefList!=None)
            {
               UTUR.Next=new(self) class 'UTUTexRef';
               UTUR=UTUR.Next;
               UTUR.Next=None;
               UTUR.TClass=TexReplacer_Decoration[i].TClass;
            }else
            {
               UTUTexRefList=new(self) class 'UTUTexRef';
               UTUTexRefList.Next=None;
               UTUR=UTUTexRefList;
               UTUR.TClass=TexReplacer_Decoration[i].TClass;
            }// endif

            NumReplacementClasses++;
            for (j=0;j<8;j++)
            {
               if(j==0)
               {
                  if(TexReplacer_Decoration[i].D0_Name!="")
                  {
                     UTUR.D0_Name=TexReplacer_Decoration[i].D0_Name;
                  }else
                  {
                     UTUR.D0_Name="";
                  }// endif
                  if(TexReplacer_Decoration[i].R0_Name!="")
                  {
                     UTUR.R0_Name=TexReplacer_Decoration[i].R0_Name;
                  }else
                  {
                     UTUR.R0_Name="";
                  }// endif
               }else if(j==1)
               {
                  if(TexReplacer_Decoration[i].D1_Name!="")
                  {
                     UTUR.D1_Name=TexReplacer_Decoration[i].D1_Name;
                  }else
                  {
                     UTUR.D1_Name="";
                  }// endif
                  if(TexReplacer_Decoration[i].R1_Name!="")
                  {
                     UTUR.R1_Name=TexReplacer_Decoration[i].R1_Name;
                  }else
                  {
                     UTUR.R1_Name="";
                  }// endif
               }else if(j==2)
               {
                  if(TexReplacer_Decoration[i].D2_Name!="")
                  {
                     UTUR.D2_Name=TexReplacer_Decoration[i].D2_Name;
                  }else
                  {
                     UTUR.D2_Name="";
                  }// endif
                  if(TexReplacer_Decoration[i].R2_Name!="")
                  {
                     UTUR.R2_Name=TexReplacer_Decoration[i].R2_Name;
                  }else
                  {
                     UTUR.R2_Name="";
                  }// endif
               }else if(j==3)
               {
                  if(TexReplacer_Decoration[i].D3_Name!="")
                  {
                     UTUR.D3_Name=TexReplacer_Decoration[i].D3_Name;
                  }else
                  {
                     UTUR.D3_Name="";
                  }// endif
                  if(TexReplacer_Decoration[i].R3_Name!="")
                  {
                     UTUR.R3_Name=TexReplacer_Decoration[i].R3_Name;
                  }else
                  {
                     UTUR.R3_Name="";
                  }// endif
               }else if(j==4)
               {
                  if(TexReplacer_Decoration[i].D4_Name!="")
                  {
                     UTUR.D4_Name=TexReplacer_Decoration[i].D4_Name;
                  }else
                  {
                     UTUR.D4_Name="";
                  }// endif
                  if(TexReplacer_Decoration[i].R4_Name!="")
                  {
                     UTUR.R4_Name=TexReplacer_Decoration[i].R4_Name;
                  }else
                  {
                     UTUR.R4_Name="";
                  }// endif
               }else if(j==5)
               {
                  if(TexReplacer_Decoration[i].D5_Name!="")
                  {
                     UTUR.D5_Name=TexReplacer_Decoration[i].D5_Name;
                  }else
                  {
                     UTUR.D5_Name="";
                  }// endif
                  if(TexReplacer_Decoration[i].R5_Name!="")
                  {
                     UTUR.R5_Name=TexReplacer_Decoration[i].R5_Name;
                  }else
                  {
                     UTUR.R5_Name="";
                  }// endif
               }else if(j==6)
               {
                  if(TexReplacer_Decoration[i].D6_Name!="")
                  {
                     UTUR.D6_Name=TexReplacer_Decoration[i].D6_Name;
                  }else
                  {
                     UTUR.D6_Name="";
                  }// endif
                  if(TexReplacer_Decoration[i].R6_Name!="")
                  {
                     UTUR.R6_Name=TexReplacer_Decoration[i].R6_Name;
                  }else
                  {
                     UTUR.R6_Name="";
                  }// endif 
               }else if(j==7)
               {
                  if(TexReplacer_Decoration[i].D7_Name!="")
                  {
                     UTUR.D7_Name=TexReplacer_Decoration[i].D7_Name;
                  }else
                  {
                     UTUR.D7_Name="";
                  }// endif
                  if(TexReplacer_Decoration[i].R7_Name!="")
                  {
                     UTUR.R7_Name=TexReplacer_Decoration[i].R7_Name;
                  }else
                  {
                     UTUR.R7_Name="";
                  }// endif
               }// endif
            }// end for

            if(Debug)
            {
               log(i@UTUR.TClass@"LOADING DATA");
               log("MultiSkins[0] DEFAULT="@UTUR.D0_Name);
               log("MultiSkins[1] DEFAULT="@UTUR.D1_Name);
               log("MultiSkins[2] DEFAULT="@UTUR.D2_Name);
               log("MultiSkins[3] DEFAULT="@UTUR.D3_Name);
               log("MultiSkins[4] DEFAULT="@UTUR.D4_Name);
               log("MultiSkins[5] DEFAULT="@UTUR.D5_Name);
               log("MultiSkins[6] DEFAULT="@UTUR.D6_Name);
               log("MultiSkins[7] DEFAULT="@UTUR.D7_Name);
               log("MultiSkins[0] REPLACEMENT="@UTUR.R0_Name);
               log("MultiSkins[1] REPLACEMENT="@UTUR.R1_Name);
               log("MultiSkins[2] REPLACEMENT="@UTUR.R2_Name);
               log("MultiSkins[3] REPLACEMENT="@UTUR.R3_Name);
               log("MultiSkins[4] REPLACEMENT="@UTUR.R4_Name);
               log("MultiSkins[5] REPLACEMENT="@UTUR.R5_Name);
               log("MultiSkins[6] REPLACEMENT="@UTUR.R6_Name);
               log("MultiSkins[7] REPLACEMENT="@UTUR.R7_Name);
               log("--------------------------------------------------------------------------------------");
            }// endif
         }else
         {
            if(Debug)
            {
               log(i@TexReplacer_Decoration[i].TClass@"NO DATA");
               log("--------------------------------------------------------------------------------------");
            }// endif
         }// endif
      }// end for

      if(UTUTexRefList!=None)
      {
         if(Debug)
         {
            UTUR=UTUTexRefList;
            log("UTUClient_Decoration: Classes that have Replacement Textures Designated :");
            for(i=0;i<NumReplacementClasses;i++)
            {
               log("UTUClient_Decoration:"@i@")"@UTUR.TClass);
               UTUR=UTUR.Next;
            }// end for
            log("--------------------------------------------------------------------------------------");
         }// endif
      }else
      {
         log("UTUClient_Decoration: No Classes have been listed on Client in UnrealTextureUpgrade.ini as having Available Replacement Textures. Terminating UTUClient_Decoration."); 
         self.Destroy();
      }// endif
   }// endif

}// end event UTUClient_Decoration.PreBeginPlay

//=============================================================================
// UTUClient_Decoration.BeginPlay
//=============================================================================
event BeginPlay()
{
   local Decoration DecPtr;

   Super.BeginPlay();

   if( Level.Netmode!=NM_DedicatedServer && Level.Netmode!=NM_ListenServer )
   {
      foreach AllActors(Class'Decoration', DecPtr)
      {
         if(DecPtr!=None)
         {
            if(Debug)
            {
               log("--------------------------------------------------------------------------------------");
               log("UTUClient: Target Decoration:"@DecPtr@"| Target Class:"@DecPtr.Class);
            }//endif

            if(IsSupportedClass(DecPtr))
            {
               ReplaceTextures(DecPtr); 
            }// endif
            
         }// endif
      }// end foreach
   }// endif   
 
}// end UTUClient_Decoration.BeginPlay


//=============================================================================
// UTUClient_Decoration.IsSupportedClass
//=============================================================================
function bool IsSupportedClass (Actor Other)
{
   local string S,T,R,D;
   local int i, j;

   S=string(Other.Class);

   UTUR=FindMatchingClass(S);

   if(UTUR==None)
   {
      if(Debug){ log("UTUClient_Decoration: Target Actor:"@Other@"| Unsupported Class:"@S);}// endif
      return False;
   }else
   {
      T=UTUR.TClass;

      if(T!=S)
      {
         if(Debug){log("UTUClient_Decoration: ERROR FINDING MATCHING CLASS");}// endif
         return False;   
      }else
      {
         if(Debug){ log("UTUClient_Decoration: Target Actor:"@Other@"| Supported Replacement Class:"@T);}// endif
         return True;
      }// endif
   }// endif 
   return False;

}// end function UTUClient_Decoration.IsSupportedClass


//=============================================================================
// UTUClient_Decoration.FindMatchingClass
//=============================================================================
function UTUTexRef FindMatchingClass(string s)
{
   local UTUTexRef Result;

   UTUR=UTUTexRefList;

   do
   {
      if(s==UTUR.TClass)
      {
         Result=UTUR;
         return (Result);
      }else
      {
         if(UTUR.Next!=None)
         {
            UTUR=UTUR.Next;
         }else
         {
            return None;
         }// endif
      }// endif

   }until(Result!=None)

}// end function UTUClient_Decoration.FindMatchingClass


//=============================================================================
// UTUClient_Decoration.ReplaceTextures
//=============================================================================
function ReplaceTextures(Actor Other)
{
   local int j;
   local string R,D;

   for (j=0;j<8;j++)
   {
      if(j==0)
      {
         D=UTUR.D0_Name;
         R=UTUR.R0_Name;
      }else if(j==1)
      {
         D=UTUR.D1_Name;
         R=UTUR.R1_Name;
      }else if(j==2)
      {
         D=UTUR.D2_Name;
         R=UTUR.R2_Name;
      }else if(j==3)
      {
         D=UTUR.D3_Name;
         R=UTUR.R3_Name;
      }else if(j==4)
      {
         D=UTUR.D4_Name;
         R=UTUR.R4_Name;
      }else if(j==5)
      {
         D=UTUR.D5_Name;
         R=UTUR.R5_Name;
      }else if(j==6)
      {
         D=UTUR.D6_Name;
         R=UTUR.R6_Name;
      }else if(j==7)
      {
         D=UTUR.D7_Name;
         R=UTUR.R7_Name;
      }// endif

      if(D=="" || R=="")
      {
         // Skip Texture Assignment
      }else
      {
         if(Debug){ log("Texture Number:"@j@"- Replacement Texture:"@R@"- Default Texture:"@D);}// endif
         SwitchOutTextures(Other,j,R,D);
      }// endif
   }// end for

}// end function UTUClient_Decoration.ReplaceTextures


//=============================================================================
// UTUClient_Decoration.SwitchOutTextures
//=============================================================================
function bool SwitchOutTextures(Actor SkinTarget, byte SkinNo, string SkinName, string DefaultSkinName)
{
   local Texture NewSkin;
   local FireTexture NewFireSkin;
   local IceTexture NewIceSkin;
   local WaveTexture NewWaveSkin;
   local WetTexture NewWetSkin;

   if(Debug)
   {
      log("Replacement Texture : "$SkinTarget@".Multiskins["@SkinNo@"]=Texture'"@SkinName@"'");
      log("Default Texture : "$SkinTarget@".Multiskins["@SkinNo@"]=Texture'"@DefaultSkinName@"'");
   } // endif

//   SkinTarget.bMeshEnviromap=True;

   SkinName=ParseTextureName(SkinName);

   NewSkin = Texture(DynamicLoadObject(SkinName,class'Texture'));

   if(NewSkin != None)
   {
      if(Debug){ log("Replacement Texture Assignment Successful for"@SkinTarget);}// endif
      SkinTarget.Multiskins[SkinNo] = NewSkin;
      if(SkinNo==0)
      {
         SkinTarget.Skin = NewSkin;
      }// endif
      return True;
   }else
   {
      NewFireSkin = FireTexture(DynamicLoadObject(SkinName,class'FireTexture'));
      if(NewFireSkin != None)
      {
         if(Debug){ log("Replacement FireTexture Assignment Successful for"@SkinTarget);}// endif
         SkinTarget.Multiskins[SkinNo] = NewFireSkin;
         if(SkinNo==0)
         {
            SkinTarget.Skin = NewFireSkin;
         }// endif
         return True;
      }else
      {
         NewWaveSkin = WaveTexture(DynamicLoadObject(SkinName,class'WaveTexture'));
         if(NewWaveSkin != None)
         {
            if(Debug){ log("Replacement WaveTexture Assignment Successful for"@SkinTarget);}// endif
            SkinTarget.Multiskins[SkinNo] = NewWaveSkin;
            if(SkinNo==0)
            {
               SkinTarget.Skin = NewWaveSkin;
            }// endif
            return True;
         }else
         {
            NewWetSkin = WetTexture(DynamicLoadObject(SkinName,class'WetTexture'));
            if(NewWetSkin != None)
            {
               if(Debug){ log("Replacement WetTexture Assignment Successful for"@SkinTarget);}// endif
               SkinTarget.Multiskins[SkinNo] = NewWetSkin;
               if(SkinNo==0)
               {
                  SkinTarget.Skin = NewWetSkin;
               }// endif
               return True;
            }else
            {
               NewIceSkin = IceTexture(DynamicLoadObject(SkinName,class'IceTexture'));
               if(NewIceSkin != None)
               {
                  if(Debug){ log("Replacement IceTexture Assignment Successful for"@SkinTarget);}// endif
                  SkinTarget.Multiskins[SkinNo] = NewIceSkin;
                  if(SkinNo==0)
                  {
                     SkinTarget.Skin = NewIceSkin;
                  }// endif
                  return True;
               }else
               {
                  if(DefaultSkinName != "")
                  {
                     DefaultSkinName=ParseTextureName(DefaultSkinName);         

                     NewSkin = Texture(DynamicLoadObject(DefaultSkinName,class'Texture'));
                     if(NewSkin != None)
                     {
                        if(Debug){ log("Texture Defaulted for "$SkinTarget);}// endif
                        SkinTarget.Multiskins[SkinNo] = NewSkin;
                        if(SkinNo==0)
                        {
                           SkinTarget.Skin = NewSkin;
                        }// endif
                     }// endif
                  }// endif
                  return False;
               }// endif
            }// endif
         }// endif
      }// endif
   }// endif

}// end function UTUClient_Decoration.SwitchOutTextures


//=================================================================================
// UTUClient_Decoration.ParseTextureName
// Required for 224 compliance for DynamicLoadObject.
// Removes any Group Reference. 
//=================================================================================
function string ParseTextureName(string SkinName)
{
   local string T,P;

   // Get Texture Name
   T=SkinName;

   while(right(T,1) != "." )
   {
      T=left(T,len(T)-1);
      if (T=="") break;
   }// end while
   T=right(SkinName,len(SkinName)-len(T));

   // Get Package Name
   P=left(SkinName,len(SkinName)-len(T)-1);

   if(InStr(P,".")>0)
   {
      while(right(P,1) != ".")
      {
         P=left(P,len(P)-1);
         if (P=="") break;
      }// end while

      P=left(SkinName,len(P)-1);
 
   }// endif

   log("ParseTextureName :"@P@T);

   return(P$"."$T);
}// end function UTUClient_Decoration.ParseTextureName


//=============================================================================
// UTUClient_Decoration:defaultproperties
//=============================================================================

defaultproperties
{
				TexReplacer_Decoration(0)=(TClass="UnrealShare.Barrel",D0_Name="UnrealShare.Skins.JBarrel1")
				TexReplacer_Decoration(1)=(TClass="UnrealShare.Book",D0_Name="UnrealShare.Skins.JBook1")
				TexReplacer_Decoration(2)=(TClass="UnrealShare.BlueBook",D0_Name="UnrealShare.Skins.JBook4")
				TexReplacer_Decoration(3)=(TClass="UnrealShare.GreenBook",D0_Name="UnrealShare.Skins.JBook3")
				TexReplacer_Decoration(4)=(TClass="UnrealShare.YellowBook",D0_Name="UnrealShare.Skins.JBook2")
				TexReplacer_Decoration(5)=(TClass="UnrealShare.Boulder",D1_Name="UnrealShare.Skins.JBoulder1")
				TexReplacer_Decoration(6)=(TClass="UnrealShare.Candle",D0_Name="UnrealShare.CFLAM.cflame",D1_Name="UnrealShare.Skins.JCandle1")
				TexReplacer_Decoration(7)=(TClass="UnrealShare.Candle2",D0_Name="UnrealShare.CFLAM.cflame",D1_Name="UnrealShare.Skins.JCandl21")
				TexReplacer_Decoration(8)=(TClass="UnrealI.Cannon",D0_Name="Unreali.Effect13.FireEffect13",D1_Name="Unreali.Skins.JCannon1")
				TexReplacer_Decoration(9)=(TClass="UnrealI.HugeCannon",D0_Name="Unreali.Effect13.FireEffect13",D1_Name="Unreali.Skins.JCannon1")
				TexReplacer_Decoration(10)=(TClass="UnrealI.Chair",D1_Name="Unreali.Skins.JChair11")
				TexReplacer_Decoration(11)=(TClass="UnrealShare.Chest",D1_Name="UnrealShare.Skins.JChest1")
				TexReplacer_Decoration(12)=(TClass="UnrealI.Cryopod",D1_Name="Unreali.Skins.JCryopod1")
				TexReplacer_Decoration(13)=(TClass="UnrealI.Dice",D0_Name="Unreali.Skins.JDice1")
				TexReplacer_Decoration(14)=(TClass="UnrealShare.Drip",D0_Name="UnrealShare.Skins.JMisc1")
				TexReplacer_Decoration(15)=(TClass="UnrealI.EscapePod",D1_Name="Unreali.Skins.JEscape1")
				TexReplacer_Decoration(16)=(TClass="UnrealShare.Fan2",D1_Name="UnrealShare.Skins.Jfan21")
				TexReplacer_Decoration(17)=(TClass="UnrealI.Flag1",D0_Name="Unreali.Skins.Jflag11")
				TexReplacer_Decoration(18)=(TClass="UnrealI.Flagb",D0_Name="Unreali.Skins.Jflag12")
				TexReplacer_Decoration(19)=(TClass="UnrealI.Flag2",D1_Name="Unreali.Skins.JFlag21")
				TexReplacer_Decoration(20)=(TClass="UnrealI.Flag3",D1_Name="Unreali.Skins.Jflag31")
				TexReplacer_Decoration(21)=(TClass="UnrealI.IntroShip",D1_Name="Unreali.Skins.JIntroShip1")
				TexReplacer_Decoration(22)=(TClass="UnrealShare.Knife",D1_Name="UnrealShare.Skins.JLantern1")
				TexReplacer_Decoration(23)=(TClass="UnrealI.Lamp1",D1_Name="UnrealI.Skins.JLamp11")
				TexReplacer_Decoration(24)=(TClass="UnrealI.Lamp4",D1_Name="UnrealI.Skins.JLamp41")
				TexReplacer_Decoration(25)=(TClass="UnrealShare.Lantern",D1_Name="UnrealShare.Skins.JLantern1")
				TexReplacer_Decoration(26)=(TClass="UnrealShare.Lantern2",D1_Name="UnrealShare.Skins.JLantern1")
				TexReplacer_Decoration(27)=(TClass="UnrealShare.MonkStatue",D1_Name="UnrealShare.Skins.JMonkStatue1")
				TexReplacer_Decoration(28)=(TClass="UnrealShare.NaliStatue",D1_Name="UnrealShare.Skins.JNaliStatue1")
				TexReplacer_Decoration(29)=(TClass="UnrealI.Moon",D0_Name="Unreali.Skins.JMoon1")
				TexReplacer_Decoration(30)=(TClass="UnrealI.Moon2",D0_Name="Unreali.Skins.JMoon2")
				TexReplacer_Decoration(31)=(TClass="UnrealI.Moon3",D0_Name="Unreali.Skins.JMoon3")
				TexReplacer_Decoration(32)=(TClass="UnrealShare.Panel")
				TexReplacer_Decoration(33)=(TClass="UnrealShare.Plant1",D1_Name="UnrealShare.Skins.JPlant11")
				TexReplacer_Decoration(34)=(TClass="UnrealShare.Plant2",D1_Name="UnrealShare.Skins.JPlant21")
				TexReplacer_Decoration(35)=(TClass="UnrealShare.Plant3",D1_Name="UnrealShare.Skins.JPlant31")
				TexReplacer_Decoration(36)=(TClass="UnrealShare.Plant4",D1_Name="UnrealShare.Skins.JPlant41")
				TexReplacer_Decoration(37)=(TClass="UnrealShare.Plant5",D1_Name="UnrealShare.Skins.JPlant41")
				TexReplacer_Decoration(38)=(TClass="UnrealShare.Plant6",D1_Name="UnrealShare.Skins.JPlant61")
				TexReplacer_Decoration(39)=(TClass="UnrealShare.Plant7",D1_Name="UnrealShare.Skins.JPlant61")
				TexReplacer_Decoration(40)=(TClass="UnrealI.Robot",D1_Name="Unreali.Skins.JRobot1")
				TexReplacer_Decoration(41)=(TClass="UnrealShare.Sconce",D0_Name="UnrealShare.Skins.Jsconce1")
				TexReplacer_Decoration(42)=(TClass="UnrealShare.SeaWeed",D1_Name="UnrealShare.Skins.JSeaWeed1")
				TexReplacer_Decoration(43)=(TClass="UnrealShare.Sign1",D1_Name="UnrealShare.Skins.Jsign11")
				TexReplacer_Decoration(44)=(TClass="UnrealI.SludgeBarrel",D1_Name="Unreali.Skins.Jsbarrel1")
				TexReplacer_Decoration(45)=(TClass="UnrealShare.SteelBarrel",D0_Name="UnrealShare.Skins.Jsteelbarrel1")
				TexReplacer_Decoration(46)=(TClass="UnrealShare.TarydiumBarrel",D0_Name="UnrealShare.Skins.Jsteelbarrel2")
				TexReplacer_Decoration(47)=(TClass="UnrealShare.SteelBox",D1_Name="UnrealShare.Skins.JSteelBox1")
				TexReplacer_Decoration(48)=(TClass="UnrealShare.SmallSteelBox",D1_Name="UnrealShare.Skins.JSteelBox1")
				TexReplacer_Decoration(49)=(TClass="UnrealI.Table",D1_Name="Unreali.Skins.JTable11")
				TexReplacer_Decoration(50)=(TClass="UnrealI.Tapestry1",D1_Name="Unreali.Skins.JTap1")
				TexReplacer_Decoration(51)=(TClass="UnrealShare.Tree",D1_Name="UnrealShare.Skins.JTree11")
				TexReplacer_Decoration(52)=(TClass="UnrealShare.Tree1",D1_Name="UnrealShare.Skins.JTree11")
				TexReplacer_Decoration(53)=(TClass="UnrealShare.Tree10",D1_Name="UnrealShare.Skins.JTree101")
				TexReplacer_Decoration(54)=(TClass="UnrealShare.Tree11",D1_Name="UnrealShare.Skins.JTree111")
				TexReplacer_Decoration(55)=(TClass="UnrealShare.Tree12",D1_Name="UnrealShare.Skins.JTree121")
				TexReplacer_Decoration(56)=(TClass="UnrealShare.Tree2",D1_Name="UnrealShare.Skins.JTree21")
				TexReplacer_Decoration(57)=(TClass="UnrealShare.Tree3",D1_Name="UnrealShare.Skins.JTree31")
				TexReplacer_Decoration(58)=(TClass="UnrealShare.Tree4",D1_Name="UnrealShare.Skins.JTree41")
				TexReplacer_Decoration(59)=(TClass="UnrealShare.Tree5",D1_Name="UnrealShare.Skins.JTree51")
				TexReplacer_Decoration(60)=(TClass="UnrealShare.Tree6",D1_Name="UnrealShare.Skins.JTree61")
				TexReplacer_Decoration(61)=(TClass="UnrealShare.Tree7",D1_Name="UnrealShare.Skins.JTree71")
				TexReplacer_Decoration(62)=(TClass="UnrealShare.Tree8",D1_Name="UnrealShare.Skins.JTree81")
				TexReplacer_Decoration(63)=(TClass="UnrealShare.Tree9",D1_Name="UnrealShare.Skins.JTree91")
				TexReplacer_Decoration(64)=(TClass="UnrealShare.Urn",D1_Name="UnrealShare.Skins.Jurn1")
				TexReplacer_Decoration(65)=(TClass="UnrealShare.Vase",D1_Name="UnrealShare.Skins.JVase1")
				TexReplacer_Decoration(66)=(TClass="UnrealShare.Pottery0",D1_Name="UnrealShare.Skins.JPottery01")
				TexReplacer_Decoration(67)=(TClass="UnrealShare.Pottery1",D1_Name="UnrealShare.Skins.JPottery11")
				TexReplacer_Decoration(68)=(TClass="UnrealShare.Pottery2",D1_Name="UnrealShare.Skins.JPottery21")
				TexReplacer_Decoration(69)=(TClass="UnrealShare.Wire",D0_Name="UnrealShare.Effect25.FireEffect25",D1_Name="UnrealShare.Skins.JWire1")
				TexReplacer_Decoration(70)=(TClass="UnrealShare.SmallWire",D0_Name="UnrealShare.Effect25.FireEffect25",D1_Name="UnrealShare.Skins.JWire1")
				TexReplacer_Decoration(71)=(TClass="UnrealShare.WoodenBox",D1_Name="UnrealShare.Skins.JWoodenBox1")
				TexReplacer_Decoration(72)=(TClass="UnrealShare.MedWoodBox",D1_Name="UnrealShare.Skins.JWoodenBox1")
				TexReplacer_Decoration(73)=(TClass="UnrealShare.SmallWoodBox",D1_Name="UnrealShare.Skins.JWoodenBox1")
				TexReplacer_Decoration(74)=(TClass="UPak.BloodBlob",D0_Name="UnrealShare.Skins.RedSkin")
				TexReplacer_Decoration(75)=(TClass="UPak.CameraBook",D0_Name="UnrealShare.Skins.JBook1")
				TexReplacer_Decoration(76)=(TClass="UPak.Copter")
				TexReplacer_Decoration(77)=(TClass="UPak.FrozenMesh")
				TexReplacer_Decoration(78)=(TClass="UPak.MeltedPuddle")
				TexReplacer_Decoration(79)=(TClass="UPak.DyingNali")
				TexReplacer_Decoration(80)=(TClass="UPak.Naliskel",D0_Name="UPak.Skins.JNaliSkel10",D1_Name="UPak.Skins.JNaliSkel11")
				TexReplacer_Decoration(81)=(TClass="UPak.scoutpad",D1_Name="UPak.Skins.Jscoutpad1")
				TexReplacer_Decoration(82)=(TClass="UPak.scoutship",D1_Name="UPak.Skins.Jscout1",D2_Name="UPak.Skins.Jscout2")
				TexReplacer_Decoration(83)=(TClass="UPak.scoutshp",D1_Name="UPak.Skins.Jscout1",D2_Name="UPak.Skins.Jscout2")
				TexReplacer_Decoration(84)=(TClass="UPak.SpaceShip",D1_Name="UPak.Skins.Jspaceship1",D2_Name="UPak.Skins.Jspaceship2",D3_Name="UPak.Skins.Jspaceship3",D4_Name="UPak.Skins.Jspaceship4",D5_Name="UPak.Skins.Jspaceship5",D6_Name="UPak.Skins.Jspaceship6",D7_Name="UPak.Skins.Jspaceship7")
				TexReplacer_Decoration(85)=(TClass="UPak.MarineBox",D1_Name="UPak.SKins.Jdropbox1")
				TexReplacer_Decoration(86)=(TClass="UPak.MarineDropBox")
				TexReplacer_Decoration(87)=(TClass="UPak.TransitionDecoration",D0_Name="UnrealShare.GoldSkin")
				TexReplacer_Decoration(88)=(TClass="UPak.Decoration")
				TexReplacer_Decoration(89)=(TClass="UPak.Translator")
				RemoteRole=ROLE_None
				DrawType=DT_None
				bGameRelevant=True
}
